/***************************************************************************
 *                                                                         *
 *   Program:  6530CONT.REX                                                *
 *   Date:     July 8, 1999                                                *
 *   Author:   Jim Collins, based on original BESS.REXX by Mark D. Dean    *
 *                                                                         *
 *   Purpose:  To automate AF/REMOTE access to the BESS program.           *
 *             BESS runs on a Tandem in 6530 block mode.                   *
 *                                                                         *
 ***************************************************************************/

/*                        */ SIGNAL on HALT name TERMINATE_1
/*                        */ SIGNAL on SYNTAX name TERMINATE_2
/*                        */ SIGNAL on FAILURE name TERMINATE_3
/*                        */

/**************************** C O N S T A N T S ****************************/
/*                        */
/*                        */ parse source name
/*                        */ ProgramName = substr(name,lastpos('\',name)+1)':'
/*                        */
/* between Q-TOT screens  */       DelayTime =  60
/*                        */
/* Dial in information    */
/* Direct connect (no dial*/  NulPhoneNumber = ''
/* 800 number  to Phila.  */     PhoneNumber = "9,1-800-343-7156"
/* Direct dial to Phila.  */  AltPhoneNumber = "9,1-215-790-1928"
/*                        */      DialBackID = "104159214"
/*                        */
/* SafeGuard logon        */     LogonString = "LOGON SUPER.JZ8940A"
/*                        */   LogonPassword = "AUTOOP"
/*                        */
/*                        */   StartOpString = "BESSP"
/*                        */ StartOpPassword = "POPER"
/*                        */
/*                        */      FBBCommand = "O PAT"
/*                        */      RunCommand = "RUN BESS"
/*                        */
/* BESS logon             */    BessOperator = "MALINOW"
/*                        */    BessPassword = "AUTOOP"
/*                        */   BessMajorFunc = "APLS"
/*                        */     BessSubFunc = "QTOT"
/*                        */      BessOffice = "FN"   /* was "PH" */
/*                        */        BessDept = "WRM"  /* was "COP" */
/*                        */
/* bright cyan on blue    */      CyanOnBlue = "[1;36;44m"
/* bright white on blue   */     WhiteOnBlue = "[1;37;44m"
/* bright yellow on blue  */    YellowOnBlue = "[1;33;44m"
/*                        */
/*                        */  IdleDisplayPos = '1b'x'[22;10H'
/*                        */
/*                        */    BessEmulator = 'BessEmulator'
/*                        */ BessQlimitsFile = "q_limits.dat"
/* 8:30 A.M.              */       StartTime = "07:30"
/* 7:30 P.M.              */        StopTime = "22:30"
/*                        */         RunFlag = 1
/*                        */        TimeFlag = 0
/*                        */
/* Convert time to minutes*/  parse var StartTime h ':' m;
/* after midnight (form   */      StartTime = h * 60 + m
/* returned by time('M')  */  parse var  StopTime h ':' m;
/*                        */      StopTime = h * 60 + m
/*                        */
/*                        */   ScrnStrt   = 5*80
/*                        */   ScrnLen    = 16*80
/*                        */
/* List of exposed vari-  */ CONSTANTS = "DelayTime DialBackID PhoneNumber",
/* ables                  */    "LogonString LogonPassword StartOpString",
/*                        */    "StartOpPassword FBBCommand RunCommand",
/*                        */    "BessOperator BessPassword BessMajorFunc",
/*                        */    "BessSubFunc BessOffice BessDept qName.",
/*                        */    "qSetting. qValue. qRexxCommand. nLimits",
/*                        */    "CyanOnBlue WhiteOnBlue YellowOnBlue RunFlag",
/*                        */    "StartTime StopTime ProgramName IdleDisplayPos",
/*                        */    "ScrnStrt ScrnLen TimeFlag"
/**************************/
/*  Main Program Start    */
/*                        */
/* Set screen color       */ say WhiteOnBlue
/* Clear screen           */ nul = afr_cls()
/* Attempt to select      */ if afr_select(BessEmulator) <> 0 then
/*   Tandem session       */    do
/*                        */    s = ProgramName': unable to select session'
/*                        */    say s
/*                        */    n = afr_error(s,1);
/*                        */    exit
/*                        */    end
/*                        */
/* read the file          */
/* Q_LIMITS.DAT for the   */
/* HI/LO limit values;    */
/*                        */
/* Initialize entry count */ nLimits = 0
/*                        */
/* Read while not EOF     */ do while ( lines( BessQlimitsFile) > 0 )
/* Read next line         */    line = linein( BessQlimitsFile )
/* if comment, skip it    */    if ( substr( line, 1, 1 ) = ";" ) then
/*                        */       iterate
/*                        */
/* if blank line, skip it */    if ( words(line) < 4 ) then
/*                        */       iterate
/*                        */
/* good dataline; use it  */    nLimits = nLimits + 1
/* get its NAME           */    parse var line qName.nLimits line
/* get its HI/LO setting  */    parse var line qSetting.nLimits line
/* get its VALUE          */    parse var line qValue.nLimits line
/* get its REXX Command   */    qRexxCommand.nLimits = strip( line, "B" )
/*                        */ end
/*                        */
/* Tell about control data*/ say ProgramName "Read" nLimits "queue limit settings from "BessQlimitsFile"."
/*   read                 */ nul = afr_log( "Read" nLimits "queue limit settings from" BessQlimitsFile"." )
/*                        */
/* main program loop      */
/* While not operator halt*/ do while RunFlag <> 0
/* While working hours    */     do while BESSTimeCheck() = 1
/* Every five seconds     */         n = afr_suspend(5000)
/* Check for halt request */         call BESSKeyCheck
/*    if requested        */         if RunFlag = 0 then
/*       shutdown         */             signal TERMINATE_DONE
/*                        */         end
/*                        */     n = stream(BessQlimitsFile,'C','close');
/*                        */
/* logon to Interceptor   */     call DialUp
/*                        */
/* logon to SafeGuard     */     call SAFEGUARDlogon
/*                        */
/* logon to BESS          */     call BESSlogon
/*                        */
/* log off SafeGuard      */     call SAFEGUARDLogoff
/*                        */
/*                        */     say ProgramName':' date() time() "Terminal mode:" Tandem6530Mode()
/*                        */
/*                        */     do i = 1 to 60 while RunFlag <> 0
/*                        */        n = afr_suspend(1000)
/*                        */        call BESSKeyCheck
/*                        */        end
/*                        */
/*                        */     if TimeFlag <> 0 then
/*                        */       do
/*                        */       TimeFlag = 0
/*                        */       RunFlag = 1
/*                        */       end
/*                        */
/*                        */     end /* while RunFlag <>= 0 */
/*                        */ exit
/*                        */
/*                        */ TERMINATE_DONE:
/*                        */     say ; say ProgramName"TERMINATING after shutdown request"
/*                        */     signal TERMINATE
/*                        */ TERMINATE_1:
/*                        */    say ; say ProgramName"TERMINATING because of HALT"
/*                        */    say "   SIGNAL jump from line" SIGL
/*                        */    SIGNAL TERMINATE
/*                        */
/*                        */ TERMINATE_2:
/*                        */    say ; say ProgramName"TERMINATING because of SYNTAX"
/*                        */    say "   SIGNAL jump from line" SIGL
/*                        */    SIGNAL TERMINATE
/*                        */
/*                        */ TERMINATE_3:
/*                        */    say "   ProgramName SIGNAL jump from line" SIGL
/*                        */    say ; say "TERMINATING because of FAILURE"
/*                        */
/*                        */ TERMINATE:
/*                        */ exit
/*                        */

/***************************************************************************
 *                                                                         *
 * BESSProcess - Main data processing loop                                 *
 *                                                                         *
 ***************************************************************************/
/*                        */BESSProcess: procedure expose (CONSTANTS)
/*                        */
/* If no operator halt req*/ do while RunFlag = 1
/* call data acquistion   */    Call QueueTotals
/*                        */
/* wait DelayTime seconds */    TimeToWait = DelayTime
/* before resuming        */    do while TimeToWait > 0
/* processing.            */
/* Announce time remaining*/        call afr_say IdleDisplayPos||ProgramName date() time()
/*                        */        call afr_say ' Time Remaining to wait:' TimeToWait 'seconds'
/*                        */        TimetoWait = TimeToWait - 5
/*                        */        n = afr_suspend(5000);
/*                        */
/* Test work time done    */        if BESSTimeCheck() = 1 then
/*                        */            do
/*                        */            RunFlag = 0
/*                        */            TimeFlag = 1
/*                        */            return
/*                        */            end
/*                        */
/* Test left block mode   */        if Tandem6530Mode() <> 'B' then
/*                        */            return
/*                        */        end
/* test for input ready   */    do until afr_load(24*80+30,1) = 'E'
/* Only while in block    */      if Tandem6530Mode() <> 'B' then
/* mode.                  */        return
/*                        */      end
/* send F1                */    n = afr_send_ascii('1b'x'1' , 0);
/*                        */    n = afr_suspend(5000)
/* clear this line        */    call afr_say '1B'x'[2J'
/*                        */    end
/*                        */
/*                        */ return
/*                        */

/***************************************************************************
 *                                                                         *
 * QUEUETOTALS - process an entire Queue Totals sequence:                  *
 *    - read QTot screen                                                   *
 *    - display it                                                         *
 *    - search for trip levels (preset targets), and start scripts         *
 *    - F7 and F1 to cycle through each screen                             *
 *                                                                         *
 ***************************************************************************/
/*                        */QueueTotals: procedure expose (CONSTANTS)
/*                        */
/*                        */   Lit.1 = 'MORE RECORDS'
/*                        */   Lit.2 = 'TOTAL FOR ALL QUEUES'
/*                        */   Lit.3 = '                   '
/*                        */
/*                        */   LitIndex = 1
/*                        */   Lit = ' '
/*                        */
/*                        */   do while Tandem6530Mode() = 'B'
/*                        */      if BESSKeyCheck() = 0 then
/*                        */          leave
/*                        */
/*                        */      n = afr_suspend(5000)
/*                        */      line.23 = afr_load(23*80,80)
/*                        */      line.21 = afr_load(21*80,80)
/*                        */      if pos(Lit.1, line.23) > 0 then
/*                        */          do
/*                        */          call QueueLimits
/* test for input ready   */            do until afr_load(24*80+30,1) = 'E'
/* Only while in block    */              if Tandem6530Mode() <> 'B' then
/* mode.                  */                return
/*                        */              end
/* send F7                */          n = afr_send_ascii('1b'x'7' , 0);
/*                        */          iterate
/*                        */          end
/*                        */      if pos(Lit.2, line.21) > 0 then
/*                        */          if substr(line.23,1,19) = Lit.3 then
/*                        */              do
/*                        */              call QueueLimits
/*                        */              return
/*                        */              end
/*                        */      end /* forever */
/*                        */
/*                        */   return
/*                        */

/***************************************************************************
 *                                                                         *
 *  QUEUELIMITS - compares each of the queues defined in the file          *
 *                Q_LIMITS.DAT to what's currently displayed;  if the      *
 *                current count EQUALS or EXCEEDS the value specified      *
 *                in the file, the REXX script is started with all         *
 *                given parameters;  the file looks like this:             *
 *                                                                         *
 *                qName   HI/LO    Value    REXX Program Called            *
 *                               *
 *                 ITST     LO       3      BEEPCALL 555-1212 parm2 ...    *
 *                                                                         *
 ***************************************************************************/
/*                        */
/*                        */QueueLimits: procedure expose (CONSTANTS)
/*                        */
/*                        */ TandemScreen = afr_load(ScrnStrt, ScrnLen)
/*                        */
/* compare each of the    */ do i = 1 to nLimits
/* given Queue Limits with*/
/* this TandemScreen      */    WordPosition = wordpos( qName.i, TandemScreen)
/* if not found, get      */    if ( WordPosition = 0 ) then
/*    another             */       iterate
/*                        */
/*                        */
/*                        */    CurrentTotal = word( TandemScreen, WordPosition+1 )
/*                        */
/* LO Limit               */    if ( qSetting.i = "LO" ) then do
/*                        */       if ( CurrentTotal <= qValue.i ) then do
/* there is a trap speci- */          nul = afr_start_program( qRexxCommand.i )
/* fied for this item;    */          LogString = "Issued" qRexxCommand.i "for queue" qName.i";"
/* first grab the current */          LogString = LogString "LO limit value of" qValue.i
/* queue total that's on  */          nul = afr_log( LogString )
/* the screen, then match */          say LogString
/* it against the HI or LO*/       end
/* value in the           */
/* Q_LIMITS.DAT file.     */
/*                        */
/* FFB site is not using  */
/* LO values              */
/*                        */    end
/*                        */
/* HI Limit               */    if ( qSetting.i = "HI" ) then do
/*                        */       if ( CurrentTotal >= qValue.i ) then do
/*                        */          nul = afr_start_program( qRexxCommand.i qName.i CurrentTotal )
/*                        */          LogString = "Issued" qRexxCommand.i "for queue" qName.i";"
/*                        */          LogString = LogString "HI limit value of" qValue.i
/*                        */          nul = afr_log( LogString )
/*                        */          say LogString
/*                        */       end
/*                        */    end
/*                        */ end
/*                        */
/*                        */return 0
/*                        */

/***************************************************************************
 *                                                                         *
 * Tandem6530Mode - Return the current emulation mode:                     *
 *    Character   - 'C'                                                    *
 *    Block       - 'B'                                                    *
 *    Unknown     = '?'                                                    *
 *                                                                         *
 ***************************************************************************/
/*                        */Tandem6530Mode: Procedure expose (CONSTANTS)
/*                        */
/*                        */    return afr_load(24*80+19,1)
/*                        */

/***************************************************************************
 *                                                                         *
 * BESSKeyCheck - Test for operator keyboard activity.  Currently is       *
 *     sensitive to the pressing of the 'END' key representing operator    *
 *     requested shutdown.                                                 *
 *                                                                         *
 ***************************************************************************/
/*                        */BESSKeyCheck: Procedure expose (CONSTANTS)
/*                        */
/* check for operator     */
/* requested action       */
/*                        */    OperatorKey = afr_kbhit()
/* operator pressed a key?*/    if OperatorKey >= 0 then
/*                        */        do
/* function key?          */        if OperatorKey = 27 then
/*                        */            do
/* second byte is function*/            OperatorKey = afr_kbhit()
/*                        */            select
/* END key?               */                when OperatorKey = 82 then
/* terminate main loop    */                    RunFlag = 0
/*                        */                when OperatorKey = 49 then
/*                        */                    call ShowHelp
/*                        */                when OperatorKey = 89 then
/*                        */                    do
/*                        */                    say ProgramName'Operator paused, hit any key to resume'
/*                        */                    do while afr_kbhit() < 0
/*                        */                       nop
/*                        */                       end
/*                        */                    say ProgramName'Processing resumed'
/*                        */                    end
/*                        */                otherwise nop
/*                        */                end /* select */
/*                        */            end /* if */
/*                        */        end /* if */
/*                        */
/*                        */    return RunFlag
/*                        */

/***************************************************************************
 *                                                                         *
 * BESSTimeCheck - Check current system time in minutes against content    *
 *     of TimeStart and TimeStop.  Returns 1 if system time outside        *
 *     of those times, or the day of the week is Saturday or Sunday.       *
 *                                                                         *
 ***************************************************************************/
/*                        */BESSTimeCheck: Procedure expose (CONSTANTS)
/*                        */
/*                        */    call BESSKeyCheck
/*                        */
/*                        */    /* if day of the week is either Saturday or Sunday then flag no process */
/*                        */    if (substr(date('W'),1,1) = 'S') then
/*                        */        return 1
/*                        */
/*                        */    /* if current time before start time or after stop time then flag no process */
/*                        */    CurrentTime = time('M')
/*                        */    if (CurrentTime < StartTime) then
/*                        */        return 1
/*                        */
/*                        */    if (CurrentTime > StopTime) then
/*                        */        return 1
/*                        */
/*                        */    /* flag time to process */
/*                        */    return 0
/*                        */
/*                        */

/***************************************************************************
 *                                                                         *
 * SAFEGUARD-LOGON - after the dialup and dialback is complete, log on     *
 *                   to the Safeguard subsystem, seven step procedure.     *
 *                                                                         *
 ***************************************************************************/
/*                        */
/*                        */SAFEGUARDlogon: procedure expose (CONSTANTS)
/*                        */
/* Advise activity        */   say ProgramName"SAFEGUARD Logon -----------"
/*                        */
/* Define the steps req'd */   resp.1  = "SAFEGUARD ";
/* to logoff from SAFE-   */   send.1  = LogonString;
/* GUARD                  */
/*                        */   resp.2  = "Password:";
/*                        */   send.2  = LogonPassword;
/*                        */
/*                        */   resp.3  = "STARTOP ";
/*                        */   send.3  = StartOpString;
/*                        */
/*                        */   resp.4  = "Password:";
/*                        */   send.4  = StartOpPassword;
/*                        */
/*                        */   resp.5  = "FBBCMD";
/*                        */   send.5  = FBBCommand;
/*                        */
/*                        */   resp.6  = "=";
/*                        */   send.6  = RunCommand;
/*                        */
/*                        */   steps   = 6
/*                        */   tries   = 10
/*                        */   count   = 0
/*                        */
/* Call the step processor*/   Call SAFEGUARDLogProc
/*                        */
/*                        */   say ProgramName"SAFEGUARD Logon complete -----------"
/*                        */
/*                        */return 0

/***************************************************************************
 *                                                                         *
 * SAFEGUARD-LOGOFF                                                        *
 *    Assumes prompt '=' has been displayed                                *
 *    Step 1, Send EXIT, wait for FBBCMD                                   *
 *    Step 2, Send LOGOFF, through modem, response is NO CARRIER           *
 *                         direct connect, response is SAFEGUARD           *
 *                                                                         *
 ***************************************************************************/
/*                        */
/*                        */SAFEGUARDlogoff: procedure expose (CONSTANTS)
/* Define the steps req'd */
/* to logoff from SAFE-   */   say ProgramName'SAFEGUARD Logoff ----------------'
/* GUARD                  */
/*                        */   send.1 = 'EXIT';
/*                        */   resp.1 = '='
/*                        */
/*                        */   send.2 = 'LOGOFF'
/*                        */   resp.2 = "FBBCMD";
/*                        */
/*                        */   steps   = 2
/*                        */   tries   = 10
/*                        */   count   = 0
/*                        */
/* Call the step processor*/   call SAFEGUARDLogProc
/*                        */   say ProgramName'SAFEGUARD Logoff Complete -------'
/*                        */return 0
/*                        */

/***************************************************************************
 *                                                                         *
 * SAFEGUARD Logon - Logoff step processor                                 *
 *                                                                         *
 ***************************************************************************/
/*                        */
/*                        */SAFEGUARDLogProc:
/*                        */
/* get the current cursor */   cursor = afr_cursor()
/* compute line           */   line   = cursor % 80
/* compute length         */   column = cursor // 80
/* load from start of line*/   resp   = afr_load(line * 80, column + 1)
/*                        */
/* preposition on last    */   do step = steps to 1 by -1
/* last response received */     if resp.step = substr(resp,1,length(resp.step)) then
/*                        */        leave
/*                        */     end
/*                        */
/* boundry check          */   if step < 1 then
/*                        */     step = 1
/*                        */
/* Loop in char mode      */   do while Tandem6530Mode() <> 'B' & step <= steps
/*                        */     if count <= 0 & RunFlag = 1 then
/* On logon we need to    */       do
/* get SAFEGUARD to talk- */       n = afr_send_ascii('d'x,0)
/* to us.  A carriage     */       Say ProgramName'Looking for:'resp.step
/* return does that.      */       n = afr_suspend(2000)
/*                        */       count = tries
/*                        */       end
/* Decrement repeat count */     count = count - 1
/* get the current cursor */     cursor = afr_cursor()
/* compute line           */     line = cursor % 80
/* compute length         */     column = cursor // 80
/* load from start of line*/     resp = afr_load(line * 80, column + 1)
/* get length of response */     len = length(resp.step)
/* If we have a match     */     if substr(resp,1,len) = resp.step then
/*                        */       do
/*  Send the next command */         n = afr_send_ascii(send.step,1)
/*  Display found         */         say ProgramName'Received:'resp
/*  Display sent          */         say ProgramName'Sent:'send.step
/*  Reset try counter     */         count = tries
/*  go to the next step   */         step = step + 1
/*                        */         end
/* wait a second          */     n = afr_suspend(1000)
/*                        */     end
/* Return when all steps  */   return
/* complete               */
/***************************************************************************
 *                                                                         *
 * BESS-LOGON - LOGOFF                                                     *
 * Data arraanged as follows:                                              *
 *   lit.<panel>.<item>               panel literal to test for            *
 *   pos.<panel>.<item>               where the literal would be           *
 *   lits.<panel>                     how many to check                    *
 *   send.<panel>.<item>.<RunFlag>    string to send                       *
 *   sends.<panel>.<RunFlag>          number of string to send             *
 *    where                                                                *
 *       <panel>                      panel index                          *
 *       <item>                       item  index                          *
 *       <RunFlag>                    RunFlag = 1 - Logon                  *
 *                                    RunFlag = 0 - Logof                  *
 * This procedure works as follows:                                        *
 *    1. Search the for each literal lit at each position pos until        *
 *       all the literals are found on the panel.                          *
 *    2. When 1 satisfied, send each of the string for that panel for      *
 *       the type of activity determined by RunFlag.                       *
 *    3. When 2 is complete call BESSProcess if panel number is 5 and      *
 *       RunFlag is 1.                                                     *
 *                                                                         *
 *    Exit from this procedure occurs when emulation mode changes to the   *
 *    the character mode.                                                  *
 *                                                                         *
 *                                                                         *
 ***************************************************************************/
/*                        */BESSlogon: procedure expose (CONSTANTS)
/*                        */
/*                        */   say ProgramName'BESS Logon --------------------------'
/*                        */
/*                        */   n = afr_suspend(10000)
/*                        */
/*                        */     CR       = 'd'x
/*                        */    ESC       = '1b'x
/*                        */  F1Key       = ESC'1'
/*                        */  F4Key       = ESC'4'
/*                        */  F7Key       = ESC'7'
/* BESS LOGON PANEL       */
/* panel literal to check */    lit.1.1   = 'OPERATOR:'
/* panel literal position */    pos.1.1   = 8 * 80 + 0
/* panel literal to check */    lit.1.2   = 'PASSWORD:'
/* panel literal position */    pos.1.2   = 10 * 80 + 0
/* number of literals     */   lits.1     = 2
/* home cursor            */   send.1.1.1 = '1b'x'{'
/* first field value      */   send.1.2.1 = BessOperator||CR;
/* second  "     "        */   send.1.3.1 = BessPassword||CR;
/* third   "     "        */   send.1.4.1 = BessMajorFunc||CR;
/* forth   "     "        */   send.1.5.1 = BessSubFunc||CR;
/* fifth   "     "        */   send.1.6.1 = BessOffice||CR;
/* sixth   "     "        */   send.1.7.1 = BessDept||CR;
/* F1 key                 */   send.1.8.1 = F1KEY
/*                        */  sends.1.1   = 8
/*                        */   send.1.1.0 = 'EXIT'
/*                        */   send.1.2.0 = F1KEY;
/*                        */  sends.1.0   = 2
/* Panel after Logon      */
/* No data entry.         */    lit.2.1   = 'SYSTEM BULLETINS'
/* F1 key to move on.     */    pos.2.1   = 4 * 80 + 1
/* Not seen during Logoff */   lits.2     = 1
/*                        */   send.2.1.1 = F1KEY;
/*                        */  sends.2.1   = 1
/*                        */   send.2.1.0 = F4KEY
/*                        */  sends.2.0   = 1
/* APLS Menu selection    */
/* Only would be seen     */    lit.3.1   = 'APLS MENU SELECTION'
/* if LOGON panel not     */    pos.3.1   = 0 * 80 + 2
/* completely filled in   */   lits.3     = 1
/* (I think!)             */   send.3.1.1 = F4KEY;
/*                        */  sends.3.1   = 1
/*                        */   send.3.1.0 = F4KEY
/*                        */  sends.3.0   = 1
/*                        */
/*                        */
/* APLS function select   */    lit.4.1   = 'MENU      SELECTION'
/* panel, as previous     */    pos.4.1   = 0 * 80 + 2
/* panel.                 */   lits.4     = 1
/*                        */   send.4.1.1 = F4KEY;
/*                        */  sends.4.1   = 1
/*                        */   send.4.1.0 = F4KEY
/*                        */  sends.4.0   = 1
/*                        */
/* Data Processing Panel  */    lit.5.1   = 'QUEUE TOTALS'
/* Actually severl panels */    pos.5.1   = 0 * 80 + 13
/* Text at bottom of      */   lits.5     = 1
/* determines actual      */   send.5.1.1 = F1KEY;
/* function.  Managed     */  sends.5.1   = 1
/* my data processing     */   send.5.1.0 = F4KEY
/* procedure.             */  sends.5.0   = 1
/*                        */
/* Number of panels we're */  panels = 5
/* aware of.              */  panel  = 1
/* Check each panel type  */   do forever
/*   **** DEBUG ******    */   /*  Say ProgramName'Panel:'panel */
/* in turn.               */
/* Only while in block    */     if Tandem6530Mode() <> 'B' then
/* mode.                  */         return 1
/* Check for op request   */     call BESSKeyCheck
/*                        */
/* Zero hit counter.      */     count = 0
/* Check for each literal */     do item = 1 to lits.panel
/* Get length of literal  */       len = length(lit.panel.item)
/*   **** DEBUG ******    */    /* say ProgramName'Panel:'panel 'Item:'item 'Pos:'pos.panel.item */
/* pick up candidate lit  */       found = afr_load(pos.panel.item,len)
/*   **** DEBUG ******    */    /* Say ProgramName'Panel:'panel 'Item:'item 'find:'Lit.Panel.item */
/*   **** DEBUG ******    */    /* Say ProgramName'Panel:'panel 'Item:'item 'Found:'found */
/* Test for literal, bump */       if found = lit.panel.item then
/* hit count if a match.  */           count = count + 1
/*                        */       end  /* do item */
/* If all literals are    */     if count = lits.panel then
/* matched:               */       do
/* Send each string reqrd */         do item = 1 to sends.panel.RunFlag
/* by this panel.         */
/* Wait a bit between send*/           n = afr_suspend(250)
/* Send.                  */           n = afr_send_ascii(send.panel.item.RunFlag,0)
/*                        */           end /* do item */
/* After everything sent: */
/* If we've found the 5th */         if panel = 5 & RunFlag = 1 then
/* panel, then start the  */             do
/* data processing activty*/             call BESSProcess
/*                        */         /*  return  */
/*                        */             end
/* Wait a bit between send*/         n = afr_suspend(2000)
/* test for input ready   */         do until afr_load(24*80+30,1) = 'E'
/* Only while in block    */           if Tandem6530Mode() <> 'B' then
/* mode.                  */             return 1
/*                        */           n = afr_suspend(5000)
/*                        */           end
/* next panel             */         end /* if count */
/* maybe back around the  */     panel = panel + 1;
/* loop                   */     if panel > panels then
/*                        */       do
/*                        */       panel = 1
/* wait a bit             */       n = afr_suspend(2000)
/*                        */       end /* if */
/*                        */     end /* do forever */
/*                        */
/*                        */   return

/***************************************************************************
 *                                                                         *
 * DIAL-UP - dials the SAFEGUARD system, and gets to point where the       *
 *           first BESS screen is ready to be received, modem connection   *
 *           only.                                                         *
 *                                                                         *
 ***************************************************************************/
/*                        */DialUp: procedure expose (CONSTANTS)
/*                        */
/*                        */   if PhoneNumber = '' then
/*                        */        return 0
/*                        */
/* Only while in character*/     if Tandem6530Mode() = 'B' then
/* mode.                  */         return 1
/*                        */
/*                        */   say ProgramName'Tandem Dial-up --------------------'
/*                        */
/*                        */   say ProgramName' Continue modem dialup? (Y/N)'
/*                        */   do 30
/*                        */     n = afr_suspend(1000)
/*                        */     kb = afr_kbhit()
/*                        */     if kb > 0 then
/*                        */        do
/*                        */        kb = d2c(kb)
/*                        */        if kb = 'Y' | kb = 'y' then
/*                        */           leave
/*                        */        if kb = 'N' | kb = 'n' then
/*                        */           return 0
/*                        */        end
/*                        */     end
/*                        */
/*step action             */
/* 1   Init modem,        */   step.1.next = 2;
/*     wait for OK        */   step.1.send = 'ATS0=1E1V1X4M0';
/*                        */   step.1.resp = "OK";
/*                        */   step.1.delay = 1000;
/*                        */
/* 2   dial,              */   step.2.next = 3;
/*     wait for CONNECT   */   step.2.send = 'ATDT'PhoneNumber;
/*                        */   step.2.resp = "CONNECT";
/*                        */   step.2.delay = 1000;
/*                        */
/* 3   send <CR>,         */   step.3.next = 4;
/*     wait for Hello!    */   step.3.send = ' ';
/*                        */   step.3.resp = "Hello!";
/*                        */   step.3.delay = 1000;
/*                        */
/* 4   send logon string, */   step.4.next = 0;
/*     wait for connect   */   step.4.send = DialBackID;
/*                        */   step.4.resp = "CONNECT";
/*                        */   step.4.delay = 1000;
/*                        */
/* Initialize last step   */   step = 0
/* Initialize current step*/   i    = 1
/*                        */
/*                        */   say ProgramName'Waiting for:' step.i.resp
/*                        */
/*                        */   call CharModeDialog
/*                        */
/*                        */   say ProgramName"Successful call back."
/*                        */
/*                        */   drop step.
/*                        */
/*                        */return 0
/*                        */

/***************************************************************************
 *                                                                         *
 * Character Mode Send/Response dialog processor                           *
 *                                                                         *
 *                                                                         *
 ***************************************************************************/
/*                        */CharModeDialog:
/*                        */
/*                        */
/* for each step of the   */   do while Tandem6530Mode() = 'C' & i > 0
/* logon                  */
/*                        */
/* display whats to happen*/      if step <> i then
/* this step              */         do
/*                        */         say ProgramName'Sending:' step.i.send
/*                        */         say ProgramName'Waiting for:' step.i.resp
/*                        */         step = i
/*                        */         end
/*                        */
/*                        */
/* send next string       */      n = afr_send_ascii(step.i.send,1)
/*                        */
/* wait for the expected  */
/* response               */      call waitresponse
/*                        */
/*                        */      end
/*                        */
/*                        */   return
/*                        */

/***************************************************************************
 *                                                                         *
 * Wait Response - Character Mode                                          *
 *                                                                         *
 *                                                                         *
 ***************************************************************************/
/*                        */WaitResponse:
/*                        */
/* wait for response      */   do forever
/* i = 0 indicates that   */      if i = 0 then
/* dialog is complete     */          return i
/*                        */
/* if response searching  */      if step.i.resp = '' then
/* for is null, forget it */          do
/*                        */          i = step.i.next
/*                        */          return i
/*                        */          end
/*                        */
/* check terminal mode,   */      if Tandem6530Mode() <> 'C' then
/* if not in character    */         leave
/* mode then quit         */
/* check for user request-*/      if  BESSKeyCheck() = 0 then
/* ed shutdown            */         return 1
/*                        */
/* wait before checking   */      n = afr_suspend(step.i.delay)
/* for response           */
/* get current cursor     */      cursor = afr_cursor() - 80
/* position, go back 80   */      if cursor < 0 then
/* chars to see response  */          cursor = 0
/* pick 80 characters prev*/      line = afr_load(cursor, 80)
/* ious to current cursor */
/* position               */
/* is response present?   */      found = pos(step.i.resp, line)
/* then go to the next    */      if found > 0 then
/* step                   */          do
/*                        */          i = step.i.next
/*                        */          return i
/*                        */          end
/*                        */      end
/*                        */
/*                        */   return i

/***************************************************************************
 *                                                                         *
 *                                                                         *
 *                                                                         *
 *                                                                         *
 ***************************************************************************/

ShowHelp: procedure expose ProgramName

/* Clear screen           */  call afr_say '1B'x'[2J'
/* Display title          */  call afr_say '1b'x'[1;30H'ProgramName 'Help'
/*                        */  say ' '
/* and instructions       */  say "   Press the 'END' key to terminate execution of "ProgramName
/*                        */  say "   Press the 'PAUSE' key to suspend operation of this program"
/*                        */  say "   Press the 'F1' key to display this panel"
/*                        */  say " "
/*                        */  say " "
/*                        */  say "           Press any key to resume operation"
/*                        */
/* wait for a key press   */  do while AFR_KBHIT() = -1
/* Note: might want to    */    n = afr_suspend(500)
/* have this 'time out'   */    end
/* so we go back to pro-  */
/* cessing after a while. */  call afr_say '1B'x'[2J'
/*                        */
/*                        */  return
/*                        */
