/*************************** REXX *********************************************
   SCRIPT: AUTOEXEC.REX
   08-Jul-1999 08:30:00

   PURPOSE: This script is started automatically by RPServer as part of
            its startup procedure.  This script conditionally starts
            Time Acquisition and WTOR Beeper Paging REXX scripts.

   Inputs:  None.

   Outputs: None.

   Description:
            Program acquires the following configuration data via calls to
            AFR_GET_ENV():

               Parameter                   Field Label for AFR_GETENV

               Time Acquisition Start Flag TA_AUTOSTART
               Time Acquisition Scrip Name TA_REXXSTART
               Beeper Paging Start Flag    BP_AUTOSTART
               Beeper Paging Script Name   BP_REXXSTART

            Program acquires, from the System Environment, the TimeZone
            variable TZ.  If necessary, change the value of "min" on line 62
            to reflect shifts from GMT other than an exact hour.

            The ??_AUTOSTART parameters are tested for 'Yes' to determine if
            the Time Acquisition and Beeper Paging scripts are to be started.

            ??_REXXSTART parameters contain the name of scripts to be started
            for Time Acquisition and Beeper Paging (WTORSCAN).  These are
            tested for a non-null value before an attempt is made to use them
            to start script execution.

   Modification history:
     16APR98 JMC - modified for use by RPServer, AF/Remote on Windows NT
                   Remove Automated Desktop Startup - not a feature, AFR/NT.

     08JUL99 DFB - removed description of command line startup of Candle
                   Alert Adapter and Alert Emitter - these programs are 
                   now started via the Candle Command Center KA2 Service.

 ******************************************************************************/

/* retrieve the name of the source program */
parse source name
program_name = substr(name,lastpos('\',name)+1)':'
qPath = word(name, words(name))
qPath = left(qPath, lastpos('\', qPath))

say program_name "Started at" time() "on" date()

/* set some error detection signals */
signal on halt
signal on novalue
signal on syntax

/* retrieve the GMT to local time zone adjustment data, eg: PST8PDT */
timezone = 'AFR_GETENV'("TZ")

min = 0

/* extract the adjustment value */
hour = 0
if length(timezone) > 3 then timezone = substr(timezone,4)
if length(timezone) > 3 then hour = left(timezone,length(timezone)-3)
                        else hour = timezone

/* record the adjustment value */
if datatype(hour) == 'NUM' then rc1 = 'AFR_SETENV'("SYS_TIMEZONE",hour*60+min)

/* maybe startup Time of Day Acquisition script */
buffer = 'AFR_GETENV'("TA_AUTOSTART")
if buffer == 'Yes' then
   do
      name = 'AFR_GETENV'("TA_REXXSTART")
      if name \= '' then
         do
            say program_name "Starting Time of Day Acquisition Script" name
            rc = 'AFR_START_PROGRAM'(name)
         end
   end



/************************************************************************/
/* 4/7/98  Modified to startup A/S USRPG-based beeper paging instead    */
/*	   of WTOR Beeper paging, using the same enabling configuration */
/*	   checkbox in the Notification properties page.                */
/************************************************************************/
 
buffer = 'AFR_GETENV'("BP_AUTOSTART")  
if buffer == 'Yes' then
   do
      name = 'AFR_GETENV'("BP_REXXSTART")
      if name \= '' then
         do
            say program_name "Starting A/S USRPG Beeper Paging Script" name
            rc = 'AFR_START_PROGRAM'(name)
         end
   end


/************************************************************************/
/* 7/8/99  Removed comment lines describing how to start the AF/REMOTE  */
/*         Alert Adapter and Alert Emitter through command line         */
/*         arguments. This approach is only valid for the OS/2 versions */
/*         of the programs.  Under Windows NT, the Alert Adapter and    */
/*         Alert Emitter can either be started automatically at NT      */
/*         bootup time by configuring the Candle Command Center KA2     */
/*         Service as an auto-started service, or they can be started   */
/*         manually from the Alert Adapter Manager dialog.              */
/************************************************************************/

/* you may put the initialization in a file named AUTOUSER.REX */
/* to keep your initialization separate from AF/REMOTE's &     */
/* prevent future overwriting of your customization            */

if stream('..\scripts\AUTOUSER.REX','c','query exists') \= '' then
	do
		say  "AUTOUSER.REX found"
		call 'AUTOUSER.REX'
	end
else
	do
		say  "AUTOUSER.REX not found"
	end

/* advise completion of program */
say program_name "Terminated Normally at" time() "on" date()

/* just for drill */
return 'OK'

/* branch to this point if program halted from AF/REMOTE Client Scripts window */
halt:
   result = program_name 'Terminated by Operator'
   say result
   ret = 'AFR_ERROR'(result,1)
/* whatever else needs to be done to clean up after a shutdown */
   exit 'N'

/* branch to this point if novalue error encountered */
novalue:
   result = program_name 'Terminated for NoValue, Line' SIGL
   say result
   ret = 'AFR_ERROR'(result,0)
/* whatever else needs to be done to clean up after a No Value shutdown */
   exit 'N'

/* branch to this point if syntax error encountered or function call in error */
syntax:
   result = program_name 'Terminated for Syntax, Line' SIGL 'Code' RC
   say result
   ret = 'AFR_ERROR'(result,0)
/* whatever else needs to be done to clean up after a syntax shutdown */
   exit 'N'
