/*************************** REXX *********************************************
   SCRIPT: BEEP.REX
   16-Apr-1998 10:35:30

   PURPOSE: Default REXX script started by AUTOEXEC.REX if beeper autostart
            flag is set to 'YES'

   Inputs:  None

   Outputs: None

   Description:
            For each possible emulator
              If console type is MVS/Beeper then
                 start a REXX session for WTORSCAN.REX passing emulator
                 as an argument.
            When all selections attempted, terminate program and exit.

   Modification history:

 ******************************************************************************/

/* retrieve the name of the source program */
parse source name
program_name = substr(name,lastpos('\',name)+1)':'

say program_name "Started at" time() "on" date()

/* set some error detection signals */
signal on halt
signal on novalue
signal on syntax

/* get use/title/screen for first possible emulator */
emulator_use = 'AFR_GETENV'("E1_USE")
emulator_title = 'AFR_GETENV'("E1_TITLE")
emulator_screen = 'AFR_GETENV'("E1_SCREEN")

/* loop for all possible emulators after first */
do i = 2 to 999 until emulator_use == ""

   /* check if emulator in use */
   if emulator_use \= "None" then do

      /* inform anybody watching */
      say program_name 'Emulator' emulator_title 'is a(n)' emulator_use 'Console'

      /* check if a beeper console */
      if pos("Beeper",emulator_use) > 0 then do

         /* if beeper console, start a scanner script */
         ret = 'AFR_START_PROGRAM'("WTORSCAN.REX" emulator_title emulator_screen )
         say program_name 'Starting WTOR Beeper Paging Scan Script WTORSCAN.REX for Emulator' emulator_title
         ret = 'AFR_SUSPEND'(5000)
      end
   end

   /* get use/title for next possible emulator */
   emulator_use = 'AFR_GETENV'("E"||i||"_USE")
   emulator_title = 'AFR_GETENV'("E"||i||"_TITLE")
   emulator_screen = 'AFR_GETENV'("E"||i||"_SCREEN")
end

/* advise completion of program */
say program_name "Terminated Normally at" time() "on" date()

/* just for drill */
return 'OK'

/* branch to this point if program halted from AF/REMOTE Client Scripts window */
halt:
   result = program_name 'Terminated by Operator'
   say result
   ret = 'AFR_ERROR'(result,1)
/* whatever else needs to be done to clean up after a shutdown */
   exit 'N'

/* branch to this point if novalue error encountered */
novalue:
   result = program_name 'Terminated for NoValue, Line' SIGL
   say result
   ret = 'AFR_ERROR'(result,0)
/* whatever else needs to be done to clean up after a No Value shutdown */
   exit 'N'

/* branch to this point if syntax error encountered or function call in error */
syntax:
   result = program_name 'Terminated for Syntax, Line' SIGL 'Code' RC
   say result
   ret = 'AFR_ERROR'(result,0)
/* whatever else needs to be done to clean up after a syntax shutdown */
   exit 'N'
