/*************************** REXX *********************************************
   BEEPQSHL.REX
   16-Apr-1998 10:35:30

   Purpose:
      This is a shell which is started for each queued beeper page by BEEPQUED.
      REX.  This allows the BEEPCALL.REX or derivative to be called, capturing
      the result, and then allows a user defined program to be called to
      complete the processing of a beeper call.

   Modification history:
      July 1, 1999 - Steve Berry. Enclosed BeeperMsg in quotes prior to the
              Interpret command, which was returning Novalue.    

 ******************************************************************************/


/* set some error detection signals */
signal on syntax
signal on halt
signal on novalue

/* Suggest initialized variables be done here */
Verbose = 1

/* retrieve the name of the source program */
parse source name
program_name = substr(name,lastpos('\',name)+1)':'
say 'Starting' program_name

/* retrieve the current version and level */
parse version ver
say 'Version =' ver

/* Main line program goes here */

/* get beeper arguments */
parse arg Emulator '+/+' WTORNumber BeeperMsg
say program_name 'Emulator:'Emulator 'WtorNumber:'WtorNumber
say program_name 'BeeperMsg:'BeeperMsg

/* retrieve the name of the program to make the paging call */
BeepProgName = afr_getenv('BP_REXXCALL')

cmd = 'answer = "'BeepProgName'"("'BeeperMsg'")'
interpret cmd

if Verbose then
   say program_name WTORNumber BeeperMsg

/* Place code here to deal with result of beeper call.  The data passed into
   the program is:
      the WTOR number contained in the variable WTORNumber which is extracted
   from the WTOR text returned by AFR_CHECK_WTOR,

      the text normally transmitted to BEEPCALL.REX which is contained in the
   variable BeeperMsg.

   The result of the paging call attempt is placed in the variable answer, that
   usually is a value of 'Y' or 'N'.
   */

/* pretty good idea to return a value to the caller */
return ' '

/* branch to this point if program halted from AF/REMOTE Client Scripts window */
halt:
   result = program_name 'Terminated by Operator'
   ret = 'AFR_ERROR'(result,0)
   say result
/* whatever else needs to be done to clean up after a shutdown */
   return 'N'

/* branch to this point if syntax error encountered or function call in error */
syntax:
   result = program_name 'Terminated for Syntax, Line' SIGL
   ret = 'AFR_ERROR'(result,1)
   say result
/* whatever else needs to be done to clean up after a syntax shutdown */
   return 'N'

/* branch to this point if novalue error encountered */
novalue:
   result = program_name 'Terminated for NoValue, Line' SIGL
   ret = 'AFR_ERROR'(result,1)
   say result
/* whatever else needs to be done to clean up after a No Value shutdown */
   return 'N'


/* subroutines, functions, procedures, ??? */

