/******************************* REXX ****************************************
   CURSOR.REX
   12-Jan-1993 13:14:15

   Purpose:  Provides a sample script to display, for the selected emulator,
             the screen position of the cursor, the character at the cursor,
             and the color attribute of that screen position.

   Inputs:   No parameters.  Asks for emulator name.

   Outputs:  None.  Program must be stopped from the REXX pulldown.

 *****************************************************************************/

/* retrieve the name of the source program */
parse source name
program_name = substr(name,lastpos('\',name)+1)':'

say program_name "Started at" time() "on" date()

/* set some error detection signals */
signal on halt
signal on novalue
signal on syntax

/* PC color attributes */
attribute.0  = "Black"
attribute.1  = "Blue"
attribute.2  = "Green"
attribute.3  = "Cyan"
attribute.4  = "Red"
attribute.5  = "Magenta"
attribute.6  = "Brown"
attribute.7  = "White"
attribute.8  = "Gray"
attribute.9  = "Light Blue"
attribute.10 = "Light Green"
attribute.11 = "Light Cyan"
attribute.12 = "Light Red"
attribute.13 = "Light Magenta"
attribute.14 = "Yellow"
attribute.15 = "Bright White"

/* get name of emulator to monitor */
say program_name "Waiting for Emulator name..."
pull emulator

x = 'AFR_SELECT'(emulator)
if x \= 0 then do
   say program_name 'Invalid Emulator name:' emulator
   exit
end

screen_position = -1;
/* monitor the emulator session */
do forever
	if screen_position \= 'AFR_CURSOR'() then do

		screen_position  = 'AFR_CURSOR'()
      screen_character = 'AFR_LOAD'(screen_position,1)
      screen_attribute = 'AFR_LOAD_COLOR'(screen_position,1)
      backgroundcolor  = C2D(BITAND(screen_attribute,'f0'x))/16;
      foregroundcolor  = C2D(BITAND(screen_attribute,'0f'x));

      part1 = LEFT('At',6-LENGTH(screen_position),' ') screen_position','
      part2 = ''''screen_character''' (Hex:' C2X(screen_character)')'
      part3 = 'is' attribute.foregroundcolor 'on' attribute.backgroundcolor '(Hex:' C2X(screen_attribute)')'
		say program_name part1 part2 part3
		end

	x = 'AFR_SUSPEND'(500)
end

/* advise completion of program */
say program_name "Terminated Normally at" time() "on" date()

/* just for drill */
return 'OK'

/* branch to this point if program terminated by REXX management pulldown */
halt:
   result = program_name 'Terminated by Operator'
   say result
   ret = 'AFR_ERROR'(result,1)
/* whatever else needs to be done to clean up after a shutdown */
   exit 'N'

/* branch to this point if novalue error encountered */
novalue:
   result = program_name 'Terminated for NoValue, Line' SIGL
   say result
   ret = 'AFR_ERROR'(result,0)
/* whatever else needs to be down to clean up after a No Value shutdown */
   exit 'N'

/* branch to this point if syntax error encountered or function call in error */
syntax:
   result = program_name 'Terminated for Syntax, Line' SIGL 'Code' RC
   say result
   ret = 'AFR_ERROR'(result,0)
/* whatever else needs to be down to clean up after a syntax shutdown */
   exit 'N'

