/*************************** REXX *********************************************
   SCRIPT: MODSTAT.REX
   23-Apr-1998 12:24:28

   PURPOSE: Evaluates status return by AFR external functions AFR_MODEMCALL,
            AFR_MODEMSTATUS, AFR_MODEMHANGUP, and AFR_MODEMANSWER.  Returns
            literal string indicating the current status of the modem port.
            The status returned by these external functions contains a
            negative value in the upper eight bits and an undefined value
            in the lower eight bits.

   SYNOPSIS rc = modstat.rex(status)
               where
                  status is the status returned by AFR_MODEM????
                  rc is the modem status mnemonic string for 'status'

 Modification History:

 ******************************************************************************/


parse arg status

if datatype(status) \= 'NUM' then
   return 'INVALID STATUS'   /* Invalid parameter */

old_status = abs(status)
if old_status > 255 then
old_status = old_status / 256

select
   when old_status = 0 then
      return 'NOHANDLE'      /* modem port not opened */
   when old_status = 1 then
      return 'TIMEDOUT'      /* function time out */
   when old_status = 4 then
      return 'ERROR'         /* Unknown Error */
   when old_status = 6 then
      return 'CONNECT'       /* Modem successfully completed connection */
   when old_status = 7 then
      return 'PATHFAIL'      /* Port is not talking to modem (cable?) */
   when old_status = 8 then
      return 'DISCONNECTED'  /* Modem successfully disconneced */
   when old_status = 9 then
      return 'INPROGRESS'    /* Connection process still continuing */
   when old_status = 10 then
      return 'NOTOPENED'     /* Modem port has not been opened */
   when old_status = 11 then
      return 'PHONENOANS'    /* Phone called did not answer */
   when old_status = 12 then
      return 'PHONEBUSY'     /* Phone called returned a busy signal */
   when old_status = 13 then
      return 'NOCARRIER'     /* Phone called is not a modem */
   when old_status = 14 then
      return 'NODIAL'        /* Phone OFFHOOK, no dialtone detected */
   when old_status = 15 then
      return 'BUSY'          /* Phone called is busy */
   when old_status = 16 then
      return 'NOANS'         /* Phone called did not answer */
   when old_status = 17 then
      return 'OPEN'          /*  */
   otherwise
      return 'UNKNOWN STATUS'/* Unknown Status */
end
