/******************************* REXX ****************************************
   MONTHLY.REX
   28-Jan-1998 

   Purpose:  Provides a sample script to reallocate the LOG on the first of
             each month.  Could be started from AUTOUSER.REX if desired.

   Inputs:   No parameters.

   Outputs:  None.  Program must be halted from the Scripts panel.

   Modification History:
     28Jan98 - JMC - Modified to access RPSERVER files for AF/REMOTE on NT

 *****************************************************************************/

/* retrieve the name of the source program */
parse source name
program_name = substr(name,lastpos('\',name)+1)':'

say program_name "Started at" time() "on" date()

/* set some error detection signals */
signal on halt
signal on novalue
signal on syntax

/* determine log file name */
if '' \= stream('RPSERVER.EXE', 'c', 'query exists') then
   file_name = 'RPSERVER.LOG'
else do
   say program_name "Could not determine LOG file name"
   return
end

/* file name extensions for renamed log file */
month_table = "JAN FEB MAR APR MAY JUN JUL AUG SEP OCT NOV DEC"

/* monitor the date */
do forever

   /* get current day's date */
   day = word(date("N"), 1)

   /* if 1st, see if have to rename log */
   if day = 1 then do

      /* determine current month and find it in the table */
      current_month = translate(word(date("N"), 2))
      month_pos = wordpos(current_month, month_table)

      select
         /* if month not found in table, then name it ERR" */
         when month_pos = 0 then
             month = "ERR"

         /* else if month not first element, then use previous element */
         when month_pos > 1 then
             month = word(month_table, month_pos - 1)
 
         /* else use last element in the table */
         otherwise
             month = word(month_table, words(month_table))
      end

      /* see if a renamed log file with that extension exists */
      if '' \= stream(file_name||month, 'c', 'query exists') then do

         /* get date file was last written to */
         file_date = stream(file_name||month, 'c', 'query datetime')
         parse var file_date fm '-' fd '-' fy .

         /* and today's date */
         parse value date("O") with ty '/' tm '/' td .

         /* see if it was last written today */
         if ty = fy & tm = fm & td = fd then
            reopen_it = 0
         else
            reopen_it = 1
      end
      else reopen_it = 1
   end
   else reopen_it = 0

   /* reopen log file if necessary */
   if 1 = reopen_it then do
      ret = afr_reopen_log(month)
      if 0 = ret then
         say program_name "Log reopened at" time() "on" date() "to" file_name||month
      else
         say program_name "Log failed to rename at" time() "on" date() "to" file_name||month "code" ret
   end

   /* seconds until midnight */
   time = (24 * 60 * 60) - TIME("S")

   /* sleep until tomorrow at 00:00:05 */
   call AFR_SUSPEND (time + 5) * 1000
end

/* advise completion of program */
say program_name "Terminated Normally at" time() "on" date() 
 
/* just for drill */
return 'OK'

/* branch to this point if program terminated from Scripts panel */
halt:
   result = program_name "Terminated by Halt request"
   say result
   ret = 'AFR_ERROR'(result,1)
/* whatever else needs to be done to clean up after a shutdown */
   exit 'N'

/* branch to this point if novalue error encountered */
novalue:
   result = program_name 'Terminated for NoValue, Line' SIGL
   say result
   ret = 'AFR_ERROR'(result,0)
/* whatever else needs to be done to clean up after a No Value shutdown */
   exit 'N'

/* branch to this point if syntax error encountered or function call in error */
syntax:
   result = program_name 'Terminated for Syntax, Line' SIGL 'Code' RC
   say result
   ret = 'AFR_ERROR'(result,0)
/* whatever else needs to be done to clean up after a syntax shutdown */
   exit 'N'
