/*************************** REXX *********************************************
   PEERSEND.REX
   27-Oct-1999 09:30:00

   Purpose:
      Example of a REXX program which sends a D TS,L operator command
      to AF/OPERATOR for execution and then waits for the command response
      data to be returned.

   Modification history:
      October 27, 1999 - Dan Biskar - Initial implementation    

 ******************************************************************************/


/* set some error detection signals */
signal on halt
signal on error

/*
   Supply as parms:
   1) the IP address of the target AF/OPERATOR
   2) the peer port number of the target AF/OPERATOR
*/

parse arg destaddr destport

say 'The Destination TCP/IP Address =' destaddr
say 'The Destination TCP/IP Port ='  destport

/* If the linkid named 'AOLINK1' to AF/OPERATOR already exists, use it.
   Otherwise, call AFR_PEER_OPEN to start the link.		*/
linkid1 = AFR_PEER_QUERY( 'LINKID', destaddr )
if linkid1 = '' then
   do
      linkid1 = 'AOLINK1'
      say 'Starting AOLINK1 to AF/OPERATOR' 
      ret = AFR_PEER_OPEN( linkid1, destaddr, destport )
      if ret <> 0 then
         do 
            say 'AFR_PEER_OPEN failed with rc:' AFR_PEER_GETLASTERROR()
            exit
         end
      else
 	 say 'AFR_PEER_OPEN successful'
   end

/* Send a D TS,L command.  Request up to 2000 bytes of reply data.
   Use the AF/OPERATOR OPER RESP command.			*/
sendbuf = "OPER 'D TS,L' RESP"
rcvbuf  = AFR_PEER_SENDRCV( linkid1, 'EXEC', 2000, sendbuf )
if rcvbuf = '' then
   say 'AFR_PEER_SENDRCV failed with rc:' AFR_PEER_GETLASTERROR()
else
   say 'Received the following data from AF/OPERATOR:' rcvbuf
exit


/* Error detection handling	   */
Halt:
say 'PEERSEND.REX was halted'
/* Insert error handling code here */
EXIT

Error:
say 'PEERSEND.REX terminated with an error'
/* Insert error handling code here */
EXIT
