/*************************** REXX *********************************************
   PEERSTRT.REX
   27-Oct-1999 10:30:00

   Purpose:
      Example of a REXX script which can used to start up peer links to
      multiple AF/OPERATOR and AF/REMOTE peer systems.

   Modification history:
      October 27, 1999 - Dan Biskar - Initial implementation    

 ******************************************************************************/


/* set some error detection signals */
signal on halt
signal on error

INIT:
/* Create a list of Peer Connections to be started */
/* 
Each PEERDATA item should contain:
       1) The TCP/IP address of the destination AF peer system
       2) The TCP/IP port number of the destination AF peer system 
       3) The linkid of the AF peer system

       Example: PEERDATA.1 = '111.222.10.20 1040 AFR1'
*/

PEERDATA.0 = 4	/* Set the total number of peer connections being started */
PEERDATA.1 = '111.222.10.20 1040 AFR1'
PEERDATA.2 = '123.31.41.51  2222 AFR2'
PEERDATA.3 = '199.211.44.55 3333 AFOP1'
PEERDATA.4 = '199.211.55.66 4444 AFOP2'

MAIN:
If PEERDATA.0 > 0 then
   do
      do i = 1 to PEERDATA.0
         Parse var PEERDATA.i IP_Addr IP_Port AF_Linkid
         Link_Name = AF_Linkid
         Say 'Link Name  =' Link_Name
         Say 'IP Address =' IP_Addr
         Say 'IP Port    =' IP_Port
         /* Check to see if a link to this IP address already exists */
         Link_Check = AFR_PEER_QUERY(LINKID, IP_Addr)
         If Link_Check <> '' then
            do
               Say 'The Linkid:' Link_Check 'already exists to IP address:' IP_Addr
               Iterate
	    end
         /* If no link exists, start one */
         ret = AFR_PEER_OPEN(Link_Name, IP_Addr, IP_Port)
         If ret > 0 then
            say 'AFR Peer connection to:' IP_Addr 'failed with reason code:' ret
         else
            say 'AFR Peer connection to:' IP_Addr 'successfully started'
      end
   end
EXIT


/* Error detection handling	   */
Halt:
say 'PEERSTRT.REX was halted'
/* Insert error handling code here */
EXIT

Error:
say 'PEERSTRT.REX terminated with an error'
/* Insert error handling code here */
EXIT
