
/*************************** REXX *********************************************
   PeerNCli.REX   - Peer Non-AF Sample Client
   26-SEP-2005

   Purpose:
      To demonstrate how to initiate an AFR to AFR with no AF headers conversation.
      Note: Programs outside of AFR must use the appropriate TCP/IP APIs in place
            of the afr_peer_ functions used here
      
   See the other side of the conversation in the sample script: PeerNSvr.rex	
 
 ******************************************************************************/

/* set some error detection signals */
signal on halt
signal on error

/*-----------------------------------------------------------*/
/* OVERVIEW                                                  */
/* Two AF/Remotes (AFR-1 and AFR-2) have a conversation      */           
/* The following is the sequence of expected events:         */
/* 1) PeerNCli.rex is started on AFR-1                       */
/* 2) PeerNSvr.rex is started by the AFR-2's peer system     */
/* 3) Data is exchanged between PeerNCli and PeerNSvr        */
/*-----------------------------------------------------------*/


say "PeerNCli.rex running"...
/*-----------------------------------------------------------*/
/* Initialize the parameters                                 */
/* host: ip address of the PC running the target AF/REMOTE   */
/* link: must be "NONAF" - only one coversation allowed      */
/* type: must be "USRDATA"                                   */
/* port: must match the non-AF peer port number specified in */
/*       the host's AF/REMOTE svrprf.txt                     */
/*-----------------------------------------------------------*/
host = "9.52.123.176"
link = "NONAF"
type = "USRDATA"
port = 10018

/*-----------------------------------------------------------*/
/* OPEN                                                      */
/* If succesful the afr_peer_open call will make the         */
/* specified host AF/REMOTE start its PeerNSvr.rex script    */
/* To be succesful the target AF/REMOTE must have enabled    */
/* 'peers' and have specified the correct trusted IP address */
/*-----------------------------------------------------------*/
ret = Afr_Peer_Open(link,host,port)
if ret <> 0 then
do
  say "afr_peer_open (Error) - rc =" Afr_Peer_GetLastError()
  exit(0)
end
say "afr_peer_open() OK"


/* SEND 1 -------------------------------------------------*/
say "Sending data..."
ret = Afr_Peer_Send(link,type,"AF/Remote PeerNCli.rex calling")
if ret <> 0 then
do
  say "afr_peer_send Error - rc =" Afr_Peer_GetLastError()
  Afr_Peer_Close(link);
  exit(0)
end
say "afr_peer_send() OK"


/* RECEIVE ------------------------------------------------*/
say "Reading data..."
ret = Afr_Peer_Rcv(link,60)
if Length(ret) = 0 then
do
  say "afr_peer_rcv (Error) - rc =" Afr_Peer_GetLastError()
  Afr_Peer_Close(link);
  exit(0)
end
say "afr_peer_rcv() received: "ret


/* SEND 2 -------------------------------------------------*/
say "Sending data..."
ret = Afr_Peer_Send(link,type,"Thank you for responding")
if ret <> 0 then
do
  say "afr_peer_send Error - rc =" Afr_Peer_GetLastError()
  Afr_Peer_Close(link);
  exit(0)
end
say "afr_peer_send() OK"

/* CLOSE ---------------------------------------------------*/
afr_peer_close(link);
say "done"
exit

/*-----------------------------------------------------------*/
/* Error detection handling                                  */
/*-----------------------------------------------------------*/
Halt:
say 'PeerNCli.rex was halted'
/* Insert error handling code here */
EXIT

Error:
say 'PeerNCli.rex terminated with an error'
/* Insert error handling code here */
EXIT
