/***************************************************************************/
/*                                                                         */
/*     Program:  VOICE.REX                                                 */
/*     Date:     April, 1990                                               */
/*     Author:   Mark D. Dean                                              */
/*                                                                         */
/*     Purpose:  To provide a sample REXX program for voice functions.     */
/*                                                                         */
/*     Copyright (C) Candle Corporation, 1990-1999.  All rights reserved.  */
/*                                                                         */
/***************************************************************************/

 MUTE   = 1  /* when recording locally , MUTE outside line so no dial tone */
 NOMUTE = 0  /* when recording from outside line, don't MUTE               */

/* retrieve the name of the source program */
parse source name
program_name = substr(name,lastpos('\',name)+1)':'

say program_name "Started at" time() "on" date()

/* set some error detection signals */
signal on halt
signal on novalue
signal on syntax

   call ShowMenu

  /* loop forever, getting user's selection until he gives a 0 */

   do FOREVER

      pull Choice

     /* ------------------------------------------------------ 0 Terminate */
      if (Choice = 0) then do
         say program_name "Terminating Now"
         say " "
         ret = afr_VoiceHangup()
         exit
      end

     /* ----------------------------------------------------- 1 Initialize */
      if (Choice = 1) then do
         ret = afr_VoiceInit()

         if (ret =  0) then say " successful initialization"
         if (ret = -1) then say " error setting parameters"
         if (ret = -2) then say " error allocating channel"
         if (ret = -3) then say " error allocating line"
         if (ret = -4) then say " error setting MuteMode"
      end

     /* ----------------------------------------------------------- 2 Dial */
      if (Choice = 2) then do

         say "   give number to dial - "
         pull PhoneNumber
         nRings = 3                 /* number of rings */

         ret = afr_VoiceDial(PhoneNumber, nRings)

         if (ret =  0) then say " voice detected"
         if (ret = -1) then say " unspecified error encountered"
         if (ret = -2) then say " busy signal detected"
         if (ret = -3) then say " fast busy signal detected"
         if (ret = -4) then say " special tone detected"
         if (ret = -5) then say " timeout with no answer"
         if (ret = -6) then say " error dialing"
      end

     /* ---------------------------------------------------------- 3 Speak */
      if (Choice = 3) then do
         FileName = "test"          /* name of voice file */

         ret = afr_VoiceSpeak(FileName, 0)

         if (ret =  0) then say " successful speaking"
         if (ret = -1) then say " unspecified error encountered"
         if (ret = -2) then say " unable to access file"
         if (ret = -3) then say " error playing message"
      end

     /* ----------------------------------------------------------- 4 Beep */
      if (Choice = 4) then do
         nBeeps = 1                 /* number of beeps */

         do BeepFreq = 0 to 7
            ret = afr_VoiceBeep(nBeeps, BeepFreq)
            if (ret = -1) then say " error setting beep-tone"
            if (ret = -2) then say " error generating beep"
         end

         if (ret = 0) then say " successful beeps"
      end

     /* --------------------------------------------------- 5 Local-Record */
      if (Choice = 5) then do
         FileName = "test"          /* name of voice file */
         MaxTime = 10               /* up to 10 seconds */
         MuteMode = MUTE            /* mute dial tone */

         ret = afr_VoiceRecord(FileName, MaxTime, MuteMode)

         if (ret =  0) then say " successful record"
         if (ret = -1) then say " unspecified error"
         if (ret = -2) then say " unable to open voice file"
         if (ret = -3) then say " error recording message"
      end

     /* ---------------------------------------------------- 6 Line-Record */
      if (Choice = 6) then do
         FileName = "test"       /* name of voice file */
         MaxRecTime = 10         /* up to 10 second-long message */
         MuteMode = NOMUTE       /* don't mute outside line      */

         ret = afr_VoiceRecord(FileName, MaxRecTime, MuteMode)

         if (ret =  0) then say " successful record"
         if (ret = -1) then say " unspecified error"
         if (ret = -2) then say " unable to open voice file"
         if (ret = -3) then say " error recording message"
      end

     /* ------------------------------------------------------ 7 Get-Tones */
      if (Choice = 7) then do
         nTones = 1              /* number of tones wanted          */
         StopTone = "#"          /* return immediately if this tone */
         nSeconds = 5            /* how many seconds we'll wait     */

         TouchTones = afr_VoiceGetTones(nTones, StopTone, nSeconds)

         if (length(TouchTones) = 0) 
            then say "error collecting TouchTones"
         else 
            say "Success; tone is" TouchTones
      end

     /* --------------------------------------------------------- 8 Answer */
      if (Choice = 8) then do
         timeout = 10            /* amount of time to wait for call */
         nRings = 1              /* which ring to answer on         */

         ret = afr_VoiceAnswer(timeout, nRings)

         if (ret = 0) then say "successful answer"
         else say "error trying to answer phone"
      end

     /* ------------------------------------------------- 9 Speaker On/Off */
      if (Choice = 9) then do
         say "   give volume level (0-3) - "
         pull volume

         ret = afr_VoiceSpeaker(volume)

         if (ret = 0) then say "successful volume selection"
         else say "error setting volume"
      end

     /* -------------------------------------------------------- 10 Hangup */
      if (Choice = 10) then do
         ret = afr_VoiceHangup()

         if (ret = 0) then say "successful hangup"
         else say "error #" ret " hanging up"
      end

     /* ----------------------------------------------------- 11 Show-Menu */
      if (Choice = 11) then do
         call ShowMenu
      end

   end

/* branch to this point if program halted from AF/REMOTE Client Scripts window */
halt:
   result = program_name 'Terminated by Operator'
   say result
   ret = 'AFR_ERROR'(result,1)
   ret = afr_VoiceHangup()
/* whatever else needs to be done to clean up after a shutdown */
   exit 'N'

/* branch to this point if novalue error encountered */
novalue:
   result = program_name 'Terminated for NoValue, Line' SIGL
   say result
   ret = 'AFR_ERROR'(result,0)
   ret = afr_VoiceHangup()
/* whatever else needs to be done to clean up after a No Value shutdown */
   exit 'N'

/* branch to this point if syntax error encountered or function call in error */
syntax:
   result = program_name 'Terminated for Syntax, Line' SIGL 'Code' RC
   say result
   ret = 'AFR_ERROR'(result,0)
   ret = afr_VoiceHangup()
/* whatever else needs to be done to clean up after a syntax shutdown */
   exit 'N'

/***************************************************************************/

ShowMenu: procedure expose program_name

   rc = 'AFR_CLS'()
   say " "
   say " "
   say "                         V O I C E   C A R D   D E M O"
   say " "
   say " "

   say "    0  QUIT.                          6  Record message from line. "
   say "    1  Initialize voice card.         7  Get one Touch Tone.       "
   say "    2  Dial a number.                 8  Answer incoming call.     "
   say "    3  Play a message.                9  Turn speaker on/off.      "
   say "    4  Beep sequence.                10  Hangup outside line.      "
   say "    5  Record message from local.    11  Redisplay menu.           "
   say " "
return
